An object of class networkIRT.
- means
list, containing several matrices of point estimates for the parameters corresponding
to the inputs for the priors. The list should contain the following matrices.
alpha
A (J x 1) matrix of point estimates for politician propensity to be followed \(alpha\).
beta
A (N x 1) matrix of point estimates for follower propensity to follow others \(\beta\).
w
An (J x 1) matrix of point estimates for politician ideal points \(z\).
theta
An (N x 1) matrix of point estimates for the follower ideal points \(x\).
vars
list, containing several matrices of variance estimates for parameters corresponding
to the inputs for the priors. Note that these variances are those recovered via variational approximation,
and in most cases they are known to be far too small and generally unusable. Better estimates of variances
can be obtained manually via the parametric bootstrap. The list should contain the following matrices:
alpha
A (J x 1) matrix of variance estimates for politician propensity to be followed \(alpha\).
beta
A (N x 1) matrix of variance estimates for follower propensity to follow others \(\beta\).
w
An (J x 1) matrix of variance estimates for politician ideal points \(z\).
theta
An (N x 1) matrix of variance estimates for the follower ideal points \(x\).
runtime
A list of fit results, with elements listed as follows:
iters
integer, number of iterations run.
conv
integer, convergence flag. Will return 1 if threshold reached, and 0
if maximum number of iterations reached.
threads
integer, number of threads used to estimated model.
tolerance
numeric, tolerance threshold for convergence. Identical to thresh
argument in input to .control list.
- N
Number of followers in estimation, should correspond to number of rows in data matrix .y
J
Number of politicians in estimation, should correspond to number of columns in data matrix .y
call
Function call used to generate output.